# -*- coding: utf-8 -*-
"""
Calculate gunning fog readability score
"""
__title__ = 'py-readabilitiy-metrics'
__version__ = '0.21.1'
__author__ = 'Carmine DiMascio'
__license__ = 'MIT'
__copyright__ = 'Copyright 2018 Carmine DiMascio'

from .readability import Readability
